package it.sw.pa.comune.artegna.domain;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import it.sw.pa.comune.artegna.domain.enumeration.StatoPrenotazione;
import jakarta.persistence.*;
import java.io.Serial;
import java.io.Serializable;
import java.time.Instant;
import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

/**
 * A Prenotazione.
 */
@Entity
@Table(name = "prenotazione")
@Cache(usage = CacheConcurrencyStrategy.READ_WRITE)
@SuppressWarnings("common-java:DuplicatedBlocks")
public class Prenotazione implements Serializable {

    @Serial
    private static final long serialVersionUID = 1L;

    @Id
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "sequenceGenerator")
    @SequenceGenerator(name = "sequenceGenerator")
    @Column(name = "id")
    private Long id;

    @Column(name = "ora_inizio")
    private Instant oraInizio;

    @Column(name = "ora_fine")
    private Instant oraFine;

    @Enumerated(EnumType.STRING)
    @Column(name = "stato")
    private StatoPrenotazione stato;

    @Column(name = "motivo_evento")
    private String motivoEvento;

    @Column(name = "numero_partecipanti")
    private Integer numeroPartecipanti;

    @Column(name = "note_utente")
    private String noteUtente;

    @JsonIgnoreProperties(value = { "confermataDa", "prenotazione" }, allowSetters = true)
    @OneToOne(fetch = FetchType.LAZY)
    @JoinColumn(unique = true)
    private Conferma conferma;

    @ManyToOne(fetch = FetchType.LAZY)
    @JsonIgnoreProperties(value = { "internalUser", "liberatories" }, allowSetters = true)
    private UtenteApp utente;

    @ManyToOne(fetch = FetchType.LAZY)
    @JsonIgnoreProperties(value = { "disponibilitas", "moduliLiberatories" }, allowSetters = true)
    private Struttura struttura;

    // jhipster-needle-entity-add-field - JHipster will add fields here

    public Long getId() {
        return this.id;
    }

    public Prenotazione id(Long id) {
        this.setId(id);
        return this;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Instant getOraInizio() {
        return this.oraInizio;
    }

    public Prenotazione oraInizio(Instant oraInizio) {
        this.setOraInizio(oraInizio);
        return this;
    }

    public void setOraInizio(Instant oraInizio) {
        this.oraInizio = oraInizio;
    }

    public Instant getOraFine() {
        return this.oraFine;
    }

    public Prenotazione oraFine(Instant oraFine) {
        this.setOraFine(oraFine);
        return this;
    }

    public void setOraFine(Instant oraFine) {
        this.oraFine = oraFine;
    }

    public StatoPrenotazione getStato() {
        return this.stato;
    }

    public Prenotazione stato(StatoPrenotazione stato) {
        this.setStato(stato);
        return this;
    }

    public void setStato(StatoPrenotazione stato) {
        this.stato = stato;
    }

    public String getMotivoEvento() {
        return this.motivoEvento;
    }

    public Prenotazione motivoEvento(String motivoEvento) {
        this.setMotivoEvento(motivoEvento);
        return this;
    }

    public void setMotivoEvento(String motivoEvento) {
        this.motivoEvento = motivoEvento;
    }

    public Integer getNumeroPartecipanti() {
        return this.numeroPartecipanti;
    }

    public Prenotazione numeroPartecipanti(Integer numeroPartecipanti) {
        this.setNumeroPartecipanti(numeroPartecipanti);
        return this;
    }

    public void setNumeroPartecipanti(Integer numeroPartecipanti) {
        this.numeroPartecipanti = numeroPartecipanti;
    }

    public String getNoteUtente() {
        return this.noteUtente;
    }

    public Prenotazione noteUtente(String noteUtente) {
        this.setNoteUtente(noteUtente);
        return this;
    }

    public void setNoteUtente(String noteUtente) {
        this.noteUtente = noteUtente;
    }

    public Conferma getConferma() {
        return this.conferma;
    }

    public void setConferma(Conferma conferma) {
        this.conferma = conferma;
    }

    public Prenotazione conferma(Conferma conferma) {
        this.setConferma(conferma);
        return this;
    }

    public UtenteApp getUtente() {
        return this.utente;
    }

    public void setUtente(UtenteApp utenteApp) {
        this.utente = utenteApp;
    }

    public Prenotazione utente(UtenteApp utenteApp) {
        this.setUtente(utenteApp);
        return this;
    }

    public Struttura getStruttura() {
        return this.struttura;
    }

    public void setStruttura(Struttura struttura) {
        this.struttura = struttura;
    }

    public Prenotazione struttura(Struttura struttura) {
        this.setStruttura(struttura);
        return this;
    }

    // jhipster-needle-entity-add-getters-setters - JHipster will add getters and setters here

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof Prenotazione)) {
            return false;
        }
        return getId() != null && getId().equals(((Prenotazione) o).getId());
    }

    @Override
    public int hashCode() {
        // see https://vladmihalcea.com/how-to-implement-equals-and-hashcode-using-the-jpa-entity-identifier/
        return getClass().hashCode();
    }

    // prettier-ignore
    @Override
    public String toString() {
        return "Prenotazione{" +
            "id=" + getId() +
            ", oraInizio='" + getOraInizio() + "'" +
            ", oraFine='" + getOraFine() + "'" +
            ", stato='" + getStato() + "'" +
            ", motivoEvento='" + getMotivoEvento() + "'" +
            ", numeroPartecipanti=" + getNumeroPartecipanti() +
            ", noteUtente='" + getNoteUtente() + "'" +
            "}";
    }
}
