package it.sw.pa.comune.artegna.domain;

import java.util.Random;
import java.util.UUID;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.concurrent.atomic.AtomicLong;

public class PrenotazioneTestSamples {

    private static final Random random = new Random();
    private static final AtomicLong longCount = new AtomicLong(random.nextInt() + (2L * Integer.MAX_VALUE));
    private static final AtomicInteger intCount = new AtomicInteger(random.nextInt() + (2 * Short.MAX_VALUE));

    public static Prenotazione getPrenotazioneSample1() {
        return new Prenotazione().id(1L).motivoEvento("motivoEvento1").numeroPartecipanti(1).noteUtente("noteUtente1");
    }

    public static Prenotazione getPrenotazioneSample2() {
        return new Prenotazione().id(2L).motivoEvento("motivoEvento2").numeroPartecipanti(2).noteUtente("noteUtente2");
    }

    public static Prenotazione getPrenotazioneRandomSampleGenerator() {
        return new Prenotazione()
            .id(longCount.incrementAndGet())
            .motivoEvento(UUID.randomUUID().toString())
            .numeroPartecipanti(intCount.incrementAndGet())
            .noteUtente(UUID.randomUUID().toString());
    }
}
